#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2014 Rodolphe Quiédeville <rodolphe@quiedeville.org>
#
#     This program is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation, either version 3 of the License, or
#     (at your option) any later version.
#
#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.
#
#     You should have received a copy of the GNU General Public License
#     along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from django.core.management.base import BaseCommand
from django.conf import settings
from ... import util


class Command(BaseCommand):
    help = 'List index'

    def handle(self, *args, **options):
        """List indexes command on stdout
        Read the table book without TextField
        """
        paths = util.get_app_paths(settings)

        for path in paths:
            indexes = util.list_indexes(path)
            if len(indexes):
                self.stdout.write("-- Found %d index in %s\n" % (len(indexes),
                                                                 path))
            for index in indexes:
                self.stdout.write("%s\n" % (index['cmd']))
